@@ -2,7 +2,7 @@
 //
 // Language.h: Rcpp R/C++ interface class library -- language objects (calls)
 //
-// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -22,13 +22,6 @@
 #ifndef Rcpp_Language_h
 #define Rcpp_Language_h
 
-#include <RcppCommon.h>
-#include <Rcpp/DottedPair.h>
-#include <Rcpp/Symbol.h>
-#include <Rcpp/Function.h>
-#include <Rcpp/grow.h>
-#include <Rcpp/r_cast.h>
-
 namespace Rcpp{ 
 
     /** 
@@ -36,10 +29,18 @@ namespace Rcpp{
      *
      * This represents calls that can be evaluated
      */
-    class Language : public DottedPair {
+    RCPP_API_CLASS(Language_Impl), 
+        public DottedPairProxyPolicy< Language_Impl<StoragePolicy> > , 
+        public DottedPairImpl< Language_Impl<StoragePolicy> >
+    {
     public:
-
-        Language() ;
+        
+        typedef typename DottedPairProxyPolicy<Language_Impl>::DottedPairProxy Proxy ;
+        typedef typename DottedPairProxyPolicy<Language_Impl>::const_DottedPairProxy const_Proxy ;
+        
+        RCPP_GENERATE_CTOR_ASSIGN(Language_Impl) 
+        
+        Language_Impl(){}
         
         /**
          * Attempts to convert the SEXP to a call
@@ -47,11 +48,10 @@ namespace Rcpp{
          * @throw not_compatible if the SEXP could not be converted
          * to a call using as.call
          */
-        Language(SEXP lang) ;
+        Language_Impl(SEXP x){
+            Storage::set__( r_cast<LANGSXP>(x) ) ;    
+        }
 
-        Language(const Language& other) ;
-        Language& operator=(const Language& other) ;
-        
         /**
          * Creates a call using the given symbol as the function name
          *
@@ -61,7 +61,9 @@ namespace Rcpp{
          * > as.call( as.list( as.name( "rnorm") ) )
          * > call( "rnorm" )
          */
-        explicit Language( const std::string& symbol ); 
+        explicit Language_Impl( const std::string& symbol ){
+            Storage::set__( Rf_lang1( Rf_install(symbol.c_str()) ) ) ;
+        }
 
         /**
          * Creates a call using the given symbol as the function name
@@ -71,14 +73,18 @@ namespace Rcpp{
          * Language( Symbol("rnorm") ) makes a SEXP similar to this: 
          * > call( "rnorm" )
          */
-        explicit Language( const Symbol& symbol ); 
+        explicit Language_Impl( const Symbol& symbol ){
+            Storage::set__( Rf_lang1( symbol ) ) ;    
+        }
 
         /**
          * Creates a call to the function
          * 
          * @param function function to call
          */
-        explicit Language( const Function& function) ;
+        explicit Language_Impl( const Function& function) {
+            Storage::set__( Rf_lang1( function ) ) ;
+        }
         
         /**
          * Creates a call to the given symbol using variable number of 
@@ -97,59 +103,63 @@ namespace Rcpp{
          * 0.0 is wrapped as a numeric vector using wrap( const& double )
          * ...
          */
-#ifdef HAS_VARIADIC_TEMPLATES
-        template<typename... Args> 
-        Language( const std::string& symbol, const Args&... args) : DottedPair(Rf_install(symbol.c_str()), args...) {
-            update_language_object() ;
-        }
-        template<typename... Args> 
-        Language( const Function& function, const Args&... args) : DottedPair(function, args...) {
-            update_language_object() ;
-        }
-#else
-
-#include <Rcpp/generated/Language__ctors.h>
-
-#endif  
-        
-        /**
-         * sets the symbol of the call
-         */
-        void setSymbol( const std::string& symbol);
+        #include <Rcpp/generated/Language__ctors.h>
 
         /**
          * sets the symbol of the call
          */
-        void setSymbol( const Symbol& symbol ) ;
+        void setSymbol( const std::string& symbol){
+            setSymbol( Symbol( symbol ) ) ;    
+        }
+
+        /**
+         * sets the symbol of the call
+         */
+        void setSymbol( const Symbol& symbol ){
+            SEXP x = Storage::get__() ;
+            SETCAR( x, symbol ) ;
+            SET_TAG(x, R_NilValue);
+        }
 
         /**
          * sets the function
          */
-        void setFunction( const Function& function) ;
+        void setFunction( const Function& function){
+            SEXP x = Storage::get__() ;
+            SETCAR( x, function );
+            SET_TAG(x, R_NilValue); /* probably not necessary */ 
+        }
 
         /**
          * eval this call in the global environment
          */
-        SEXP eval() ;
+        SEXP eval() const {
+            return Rcpp_eval( Storage::get__(), R_GlobalEnv ) ;
+        }
 
         /**
          * eval this call in the requested environment
          */
-        SEXP eval(SEXP env) ;
+        SEXP eval(SEXP env) const {
+            return Rcpp_eval( Storage::get__(), env ) ;
+        }
 
-        SEXP fast_eval() ;
-        SEXP fast_eval(SEXP env ) ;
+        SEXP fast_eval() const {
+            return Rf_eval( Storage::get__(), R_GlobalEnv) ;    
+        }
+        SEXP fast_eval(SEXP env ) const {
+            return Rf_eval( Storage::get__(), env) ;    
+        }
         
-        ~Language() ;
-
-    protected:
-        void update_language_object() ; 
-
-    private:
-        void set_sexp(SEXP x) ;
+        void update( SEXP x){
+            SET_TYPEOF( x, LANGSXP ) ;
+            SET_TAG( x, R_NilValue ) ;    
+        }
         
     };
 
+    typedef Language_Impl<PreserveStorage> Language ;
+    
     template <typename OUT=SEXP>
     class fixed_call {
     public:
