@@ -3,7 +3,7 @@
 //
 // r_vector.h: Rcpp R/C++ interface class library -- information about R vectors
 //
-// Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -26,24 +26,32 @@
 namespace Rcpp{
 namespace internal{
 
-template<int RTYPE> 
-typename Rcpp::traits::storage_type<RTYPE>::type* r_vector_start(SEXP x){ return get_vector_ptr(x) ; }
-
-template<> int* r_vector_start<INTSXP>(SEXP x) ; 
-template<> int* r_vector_start<LGLSXP>(SEXP x) ;
-template<> double* r_vector_start<REALSXP>(SEXP x) ;
-template<> Rbyte* r_vector_start<RAWSXP>(SEXP x) ; 
-template<> Rcomplex* r_vector_start<CPLXSXP>(SEXP x) ;                         
+template <int RTYPE> 
+typename Rcpp::traits::storage_type<RTYPE>::type* r_vector_start(SEXP x){ 
+	typedef typename Rcpp::traits::storage_type<RTYPE>::type* pointer ;
+	return reinterpret_cast<pointer>( dataptr(x) ) ; 
+}
 
 /**
  * The value 0 statically casted to the appropriate type for 
  * the given SEXP type
  */
-template <int RTYPE,typename CTYPE> CTYPE get_zero(){ return static_cast<CTYPE>(0) ; }
+template <int RTYPE,typename CTYPE> 
+inline CTYPE get_zero(){ 
+	return static_cast<CTYPE>(0) ; 
+}
+
+
 /**
  * Specialization for Rcomplex
  */
-template<> Rcomplex get_zero<CPLXSXP,Rcomplex>() ;
+template<> 
+inline Rcomplex get_zero<CPLXSXP,Rcomplex>(){
+	Rcomplex x ;
+	x.r = 0.0 ;
+	x.i = 0.0 ;
+	return x ;
+}
 
 /**
  * Initializes a vector of the given SEXP type. The template fills the 
@@ -59,19 +67,22 @@ template<int RTYPE> void r_init_vector(SEXP x){
  * Initializes a generic vector (VECSXP). Does nothing since 
  * R already initializes all elements to NULL
  */
-template<> void r_init_vector<VECSXP>(SEXP x) ;
+template<> 
+inline void r_init_vector<VECSXP>(SEXP x){}
 
 /**
  * Initializes an expression vector (EXPRSXP). Does nothing since 
  * R already initializes all elements to NULL
  */
-template<> void r_init_vector<EXPRSXP>(SEXP x) ;
+template<> 
+inline void r_init_vector<EXPRSXP>(SEXP x){}
 
 /**
  * Initializes a character vector (STRSXP). Does nothing since 
  * R already initializes all elements to ""
  */ 
-template<> void r_init_vector<STRSXP>(SEXP x) ;
+template<> 
+inline void r_init_vector<STRSXP>(SEXP x){}
 
 } // internal
 } // Rcpp
